(Hery Phenomenal) ເປັນໂຕຢ່າງການອັພໂຫຼດ package ໄປຫາ pypi.org
============================================================

PyPi: https://pypi.org/project/phenomenal/

ສະບາຍດີ ແພ໊ຄເກຈນີ້ແມ່ນແພ໊ຄເກຈທີ່ອະທິບາຍ Profile ຂອງຂ້ອຍ ແລະ
ສາມາດນຳໄປໃຊ້ກັບຄົນອື່ນໄດ້

ວິທີຕິດຕັ້ງ
~~~~~~~~~~~

ເປີດ CMD / Terminal

.. code:: python

   pip install phenomenal

ວິທີໃຊ້ແພ໊ຄເກຈນີ້
~~~~~~~~~~~~~~~~~

-  ເປີດ IDLE ຂຶ້ນມາແລ້ວພິມ…

.. code:: python

   from phenomenal import Profile

   my = Profile('Hery')
   my.company = 'phenomenal'
   my.hobby = ['Youtuber','Reading','Sleeping']
   print(my.name)
   my.Show_email()
   my.Show_myart()
   my.Show_hobby()
   my.Show_dog()

ພັດທະນາໂດຍ: Hery Phenomenal

FB: https://www.facebook.com/HeryPhongsavath

GitHub: https://github.com/Thitphavanh
